@@ -1,6 +1,9 @@
 package JSON::Validator::Schema::Draft201909;
-use Mojo::Base 'JSON::Validator::Schema::Draft7';
+use Mojo::Base 'JSON::Validator::Schema';
 
+use JSON::Validator::Schema::Draft4;
+use JSON::Validator::Schema::Draft6;
+use JSON::Validator::Schema::Draft7;
 use JSON::Validator::Util qw(E is_type json_pointer);
 use Scalar::Util qw(blessed refaddr);
 
@@ -10,13 +13,14 @@ has specification => 'https://json-schema.org/draft/2019-09/schema';
 has _anchors      => sub { +{} };
 
 sub _build_formats {
-  my $formats = shift->SUPER::_build_formats;
+  my $formats = shift->JSON::Validator::Schema::Draft7::_build_formats;
   $formats->{duration} = JSON::Validator::Formats->can('check_duration');
   $formats->{uuid}     = JSON::Validator::Formats->can('check_uuid');
   return $formats;
 }
 
 sub _definitions_path_for_ref { ['$defs'] }
+sub _id_key                   {'$id'}
 
 sub _find_and_resolve_refs {
   my ($self, $base_url, $root) = @_;
@@ -44,7 +48,7 @@ sub _find_and_resolve_refs {
       }
 
       my $is_tied           = tied %$topic;
-      my $has_ref           = !$is_tied && $topic->{'$ref'} && !ref $topic->{'$ref'} ? 1 : 0;
+      my $has_ref           = !$is_tied && $topic->{'$ref'}          && !ref $topic->{'$ref'}          ? 1 : 0;
       my $has_recursive_ref = !$is_tied && $topic->{'$recursiveRef'} && !ref $topic->{'$recursiveRef'} ? 1 : 0;
       push @refs,           [$base_url, $topic] if $has_ref;
       push @recursive_refs, [$base_url, $topic] if $has_recursive_ref;
@@ -65,7 +69,7 @@ sub _find_and_resolve_refs {
     next if !$topic->{'$ref'} or ref $topic->{'$ref'};
     my $base = Mojo::URL->new($base_url || $base_url)->fragment(undef);
     my ($other, $ref_url, $fqn) = $self->_resolve_ref($topic->{'$ref'}, $base, $root);
-    next if $seen{$fqn}++;
+    next if $seen{$fqn}++ and tied %$topic;
     tie %$topic, 'JSON::Validator::Ref', $other, $topic, "$fqn";
     push @refs, [$fqn, $other];
   }
@@ -75,7 +79,7 @@ sub _find_and_resolve_refs {
     my ($base_url, $topic) = @{shift @recursive_refs};
     my $base = Mojo::URL->new($base_url || $base_url)->fragment(undef);
     my ($other, $ref_url, $fqn) = $self->_resolve_ref($topic->{'$recursiveRef'}, $base, $root);
-    next if $seen{$fqn}++;
+    next if $seen{$fqn}++ and tied %$topic;
     tie %$topic, 'JSON::Validator::Ref', $other, $topic, "$fqn";
   }
 }
@@ -134,6 +138,17 @@ sub _validate_type_object_dependencies {
   return @errors;
 }
 
+*_validate_number_max             = \&JSON::Validator::Schema::Draft6::_validate_number_max;
+*_validate_number_min             = \&JSON::Validator::Schema::Draft6::_validate_number_min;
+*_validate_type_array             = \&JSON::Validator::Schema::Draft6::_validate_type_array;
+*_validate_type_array_items       = \&JSON::Validator::Schema::Draft4::_validate_type_array_items;
+*_validate_type_array_min_max     = \&JSON::Validator::Schema::Draft4::_validate_type_array_min_max;
+*_validate_type_array_unique      = \&JSON::Validator::Schema::Draft4::_validate_type_array_unique;
+*_validate_type_object            = \&JSON::Validator::Schema::Draft6::_validate_type_object;
+*_validate_type_object_min_max    = \&JSON::Validator::Schema::Draft4::_validate_type_object_min_max;
+*_validate_type_object_names      = \&JSON::Validator::Schema::Draft6::_validate_type_object_names;
+*_validate_type_object_properties = \&JSON::Validator::Schema::Draft4::_validate_type_object_properties;
+
 1;
 
 =encoding utf8
