@@ -1,6 +1,7 @@
 package JSON::Validator::Schema::Draft6;
-use Mojo::Base 'JSON::Validator::Schema::Draft4';
+use Mojo::Base 'JSON::Validator::Schema';
 
+use JSON::Validator::Schema::Draft4;
 use JSON::Validator::Util qw(E data_type is_type prefix_errors);
 
 has id => sub {
@@ -66,7 +67,7 @@ sub _validate_type_array {
 
 sub _validate_type_array_contains {
   my ($self, $data, $path, $schema) = @_;
-  return unless $schema->{contains};
+  return unless exists $schema->{contains};
 
   my (@e, @errors);
   for my $i (0 .. @$data - 1) {
@@ -93,17 +94,24 @@ sub _validate_type_object {
 
 sub _validate_type_object_names {
   my ($self, $data, $path, $schema) = @_;
-  return unless my $names = $schema->{propertyNames};
+  return unless exists $schema->{propertyNames};
 
   my @errors;
   for my $name (keys %$data) {
-    next unless my @e = $self->_validate($name, $path, $names);
+    next unless my @e = $self->_validate($name, $path, $schema->{propertyNames});
     push @errors, prefix_errors propertyName => map [$name, $_], @e;
   }
 
   return @errors;
 }
 
+*_validate_type_array_items         = \&JSON::Validator::Schema::Draft4::_validate_type_array_items;
+*_validate_type_array_min_max       = \&JSON::Validator::Schema::Draft4::_validate_type_array_min_max;
+*_validate_type_array_unique        = \&JSON::Validator::Schema::Draft4::_validate_type_array_unique;
+*_validate_type_object_dependencies = \&JSON::Validator::Schema::Draft4::_validate_type_object_dependencies;
+*_validate_type_object_min_max      = \&JSON::Validator::Schema::Draft4::_validate_type_object_min_max;
+*_validate_type_object_properties   = \&JSON::Validator::Schema::Draft4::_validate_type_object_properties;
+
 1;
 
 =encoding utf8
